abjadbooktools.HTMLOutputFormat
===============================

.. abjad-lineage:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat

.. autoclass:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_block_closing
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_block_opening
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_indent
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.image_block
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.image_format
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__call__
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__eq__
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__format__
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__hash__
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__ne__
      ~abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__repr__

Bases
-----

- :py:class:`abjadbooktools.OutputFormat <abjad.tools.abjadbooktools.OutputFormat.OutputFormat>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_block_closing
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_block_opening
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.code_indent
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.image_block
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.image_format
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__format__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__hash__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.HTMLOutputFormat.HTMLOutputFormat.__repr__
   :noindex:
